==> git-url-parse-9.0.2.tgz: git-url-parse/README.md <==
# Installation
> `npm install --save @types/git-url-parse`

# Summary
This package contains type definitions for git-url-parse (https://github.com/IonicaBizau/git-url-parse).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/git-url-parse.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/git-url-parse/index.d.ts)
````ts
declare namespace gitUrlParse {
    interface GitUrl {
        /** An array with the url protocols (usually it has one element). */
        protocols: string[];
        port: number | null;
        /** The url domain (including subdomains). */
        resource: string;
        /** The authentication user (usually for ssh urls). */
        user: string;
        pathname: string;
        hash: string;
        search: string;
        href: string;
        protocol: string;
        /** The oauth token (could appear in the https urls). */
        token: string;
        /** The Git provider (e.g. `"github.com"`). */
        source: string;
        /** The repository owner. */
        owner: string;
        /** The repository name. */
        name: string;
        /** The repository ref (e.g., "master" or "dev"). */
        ref: string;
        /** A filepath relative to the repository root. */
        filepath: string;
        /** The type of filepath in the url ("blob" or "tree"). */
        filepathtype: string;
        /** The owner and name values in the `owner/name` format. */
        full_name: string;
        /** The organization the owner belongs to. This is CloudForge specific. */
        organization: string;
        /** Whether to add the `.git` suffix or not. */
        git_suffix?: boolean | undefined;
        toString(type?: string): string;
    }

    function stringify(url: GitUrl, type?: string): string;
}

declare function gitUrlParse(url: string): gitUrlParse.GitUrl;

export = gitUrlParse;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:35 GMT
 * Dependencies: none

# Credits
These definitions were written by [Klaus Meinhardt](https://github.com/ajafff).

==> git-url-parse-9.0.3.tgz: git-url-parse/README.md <==
# Installation
> `npm install --save @types/git-url-parse`

# Summary
This package contains type definitions for git-url-parse (https://github.com/IonicaBizau/git-url-parse).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/git-url-parse.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/git-url-parse/index.d.ts)
````ts
declare namespace gitUrlParse {
    interface GitUrl {
        /** An array with the url protocols (usually it has one element). */
        protocols: string[];
        port: number | null;
        /** The url domain (including subdomains). */
        resource: string;
        /** The authentication user (usually for ssh urls). */
        user: string;
        pathname: string;
        hash: string;
        search: string;
        href: string;
        protocol: string;
        /** The oauth token (could appear in the https urls). */
        token: string;
        /** The Git provider (e.g. `"github.com"`). */
        source: string;
        /** The repository owner. */
        owner: string;
        /** The repository name. */
        name: string;
        /** The repository ref (e.g., "master" or "dev"). */
        ref: string;
        /** A filepath relative to the repository root. */
        filepath: string;
        /** The type of filepath in the url ("blob" or "tree"). */
        filepathtype: string;
        /** The owner and name values in the `owner/name` format. */
        full_name: string;
        /** The organization the owner belongs to. This is CloudForge specific. */
        organization: string;
        /** Whether to add the `.git` suffix or not. */
        git_suffix?: boolean | undefined;
        toString(type?: string): string;
    }

    function stringify(url: GitUrl, type?: string): string;
}

declare function gitUrlParse(url: string): gitUrlParse.GitUrl;

export = gitUrlParse;

````

### Additional Details
 * Last updated: Tue, 07 Nov 2023 03:09:37 GMT
 * Dependencies: none

# Credits
These definitions were written by [Klaus Meinhardt](https://github.com/ajafff).
